==> grafana-container-v4.1.1-201906040019.tar.gz: grafana-container-v4.1.1-201906040019/docs/sources/tutorials/screencasts.md <==
+++
title = "Screencasts"
type = "docs"
[menu.docs]
identifier = "screencasts"
parent = "guides"
weight = 10
+++

# Screencasts

<div class="video-card-container">
  <figure class="video-card">
    <a href="https://youtu.be/iUj6DwfBh88?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/iUj6DwfBh88?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #10 Dashboard Discovery & Sharing
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/d6KicssNzxM?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/d6KicssNzxM?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #9 Using Elasticsearch in Grafana
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/1kJyQKgk_oY?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/1kJyQKgk_oY?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #8 What's new in Grafana 3.0
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/sKNZMtoSHN4?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/sKNZMtoSHN4?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #7 Beginners guide to building dashboards
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/9ZCMVNxUf6s?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/9ZCMVNxUf6s?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #6 Adding data sources, users & orgs.
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/E-gMFv84FE8?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/E-gMFv84FE8?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #5 Install & Setup on Redhat / Centos
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/JY22EBOR9hQ?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/JY22EBOR9hQ?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #4 Install & Setup on Ubuntu / Debian
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/FC13uhFRsVw?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/FC13uhFRsVw?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #3 What's New In Grafana 2.0
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/FhNUrueWwOk?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/FhNUrueWwOk?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #2 Templated Graphite Queries
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/mgcJPREl3CU?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/mgcJPREl3CU?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #1 Building Graphite Queries
       </a>
    </figcaption>
  </figure>
</div>

==> grafana-container-v4.5.0-202009161248.p0.tar.gz: grafana-container-v4.5.0-202009161248.p0/docs/sources/tutorials/screencasts.md <==
+++
title = "Screencasts"
type = "docs"
[menu.docs]
identifier = "screencasts"
parent = "guides"
weight = 10
+++

# Screencasts

<div class="video-card-container">
  <figure class="video-card">
    <a href="https://youtu.be/iUj6DwfBh88?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/iUj6DwfBh88?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #10 Dashboard Discovery and Sharing
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/d6KicssNzxM?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/d6KicssNzxM?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #9 Using Elasticsearch in Grafana
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/1kJyQKgk_oY?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/1kJyQKgk_oY?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #8 What's new in Grafana 3.0
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/sKNZMtoSHN4?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/sKNZMtoSHN4?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #7 Beginners guide to building dashboards
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/9ZCMVNxUf6s?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/9ZCMVNxUf6s?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
        #6 Adding data sources, users and orgs.
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/E-gMFv84FE8?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/E-gMFv84FE8?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #5 Install and Setup on Redhat / Centos
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/JY22EBOR9hQ?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/JY22EBOR9hQ?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #4 Install and Setup on Ubuntu / Debian
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/FC13uhFRsVw?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/FC13uhFRsVw?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #3 What's New In Grafana 2.0
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/FhNUrueWwOk?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/FhNUrueWwOk?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #2 Templated Graphite Queries
       </a>
    </figcaption>
  </figure>
  <figure class="video-card">
    <a href="https://youtu.be/mgcJPREl3CU?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
      <img src="/img/docs/v4/screencast_generic.png">
      <i class="fa fa-play"></i>
    </a>
    <figcaption>
       <a href="https://youtu.be/mgcJPREl3CU?list=PLDGkOdUX1Ujo3wHw9-z5Vo12YLqXRjzg2" target="_blank" rel="noopener noreferrer">
       #1 Building Graphite Queries
       </a>
    </figcaption>
  </figure>
</div>
